core/infinite_query_controller library

Classes

InfiniteQueryController<T, TPageParam>
Manages the state and operations for an infinite query, handling data fetching across multiple pages.
InfiniteQueryState<T>
Represents the state of an infinite query, holding pages of data of type T.