InfiniteQueryController<T, TPageParam> class
Manages the state and operations for an infinite query, handling data fetching across multiple pages.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
InfiniteQueryState< T> > - InfiniteQueryController
Constructors
- InfiniteQueryController({required String queryKey, required QueryCache cache})
- Creates a new InfiniteQueryController.
Properties
- cache → QueryCache
-
The cache used to store this controller.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- queryKey → String
-
The unique key associated with this query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
↔ InfiniteQueryState<
T> -
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
fetch(
{required Future< T> fetcher(TPageParam?), required TPageParam? getNextPageParam(T lastPage, List<T> allPages)}) → Future<void> - Fetches the initial page of data.
-
fetchNextPage(
) → Future< void> - Fetches the next page of data if available.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited