MutationController<TData, TError, TVariables> class

Controls the execution and state of a mutation.

Inheritance

Constructors

MutationController({required Future<TData> mutationFn(TVariables), void onSuccess(TData, TVariables)?, void onError(TError, TVariables)?})
Creates a new MutationController.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
mutationFn Future<TData> Function(TVariables)
The function that executes the mutation.
final
onError → void Function(TError, TVariables)?
Optional callback invoked when the mutation fails.
final
onSuccess → void Function(TData, TVariables)?
Optional callback invoked when the mutation succeeds.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value MutationState<TData, TError>
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
mutate(TVariables variables) Future<TData>
Executes the mutation with the given variables.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited