isFetchingNextPage property
bool
get
isFetchingNextPage
Whether the query is currently fetching the next page.
Implementation
bool get isFetchingNextPage => state.isFetchingNextPage;
Whether the query is currently fetching the next page.
bool get isFetchingNextPage => state.isFetchingNextPage;