QueryBuilder<T> class

A widget that builds itself based on the state of a query.

Inheritance

Constructors

QueryBuilder({Key? key, required String queryKey, required Future<T> fetcher(), required Widget builder(BuildContext context, QueryState<T> state), Duration staleTime = Duration.zero, Duration cacheTime = const Duration(minutes: 5), int retries = 3})
Creates a new query builder widget.
const

Properties

builder Widget Function(BuildContext context, QueryState<T> state)
The widget builder that takes the current QueryState as input.
final
cacheTime Duration
The duration the data is cached for.
final
fetcher Future<T> Function()
The function that fetches the data.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
queryKey String
The unique key for the query.
final
retries int
The number of times to retry a failed query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staleTime Duration
The duration until the data is considered stale.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() → _StatelessHookElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited