QueryCache class

A basic cache meant to store QueryControllers and InfiniteQueryControllers by queryKey.

Constructors

QueryCache()
Creates a new QueryCache instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build<T>(String queryKey) QueryController<T>
Gets an existing QueryController or creates a new one for the given queryKey.
buildInfinite<T, TPageParam>(String queryKey) InfiniteQueryController<T, TPageParam>
Gets an existing InfiniteQueryController or creates a new one for the given queryKey.
clear() → void
Clears the cache and disposes all query controllers.
get(String queryKey) → dynamic
Retrieves an existing controller for the given queryKey.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String queryKey) → void
Removes the controller associated with the given queryKey from the cache and disposes it.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited