InfiniteQueryResult<T> class
Represents the result of an infinite query.
Constructors
-
InfiniteQueryResult(InfiniteQueryState<
T> state, Future<void> fetchNextPage()) - Creates a new infinite query result.
Properties
-
data
→ List<
T> ? -
The data returned by the query.
no setter
- error → dynamic
-
The error returned by the query, if any.
no setter
-
fetchNextPage
→ Future<
void> Function() -
A function to fetch the next page of data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNextPage → bool
-
Whether the query has a next page.
no setter
- isError → bool
-
Whether the query resulted in an error.
no setter
- isFetchingNextPage → bool
-
Whether the query is currently fetching the next page.
no setter
- isLoading → bool
-
Whether the query is currently loading.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ InfiniteQueryState<
T> -
The state of the infinite query.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited