MutationResult<TData, TError, TVariables> class
Represents the result of a mutation.
Constructors
-
MutationResult(MutationState<
TData, TError> state, Future<TData> mutate(TVariables)) - Creates a new mutation result.
Properties
- data → TData?
-
The data returned by the mutation.
no setter
- error → TError?
-
The error returned by the mutation, if any.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
Whether the mutation resulted in an error.
no setter
- isLoading → bool
-
Whether the mutation is currently loading.
no setter
- isSuccess → bool
-
Whether the mutation was successful.
no setter
-
mutate
→ Future<
TData> Function(TVariables) -
A function to execute the mutation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ MutationState<
TData, TError> -
The state of the mutation.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited